#!/usr/bin/env rspec

require_relative "test_helper"
require "yaml"

Yast.import "AutoinstPartPlan"
Yast.import "Profile"

describe Yast::AutoinstPartPlan do
  FIXTURES_PATH = File.join(File.dirname(__FILE__), 'fixtures')
  let(:target_map_path) { File.join(FIXTURES_PATH, 'storage', "nfs_root.yml") }
  let(:target_map_clone) { File.join(FIXTURES_PATH, 'storage', "target_clone.yml") }

  describe "#read partition target" do

    it "exporting nfs root partition" do
      target_map = YAML.load_file(target_map_path)

      expect(Yast::Storage).to receive(:GetTargetMap).and_return(target_map)
      expect(Yast::AutoinstPartPlan.Read).to eq(true)
      expect(Yast::AutoinstPartPlan.Export).to eq(
         [{"type"=>:CT_NFS,
            "partitions"=>[{"type"=>:nfs,
              "device"=>"192.168.4.1:/srv/nfsroot/sles12sp1",
              "mount"=>"/",
              "fstopt"=>"minorversion=1"}],
            "device"=>"/dev/nfs", "use"=>"all"}
         ]
        )
    end

    it "ignoring not needed devices" do
      target_map = YAML.load_file(target_map_clone)

      expect(Yast::Storage).to receive(:GetTargetMap).and_return(target_map)
      expect(Yast::AutoinstPartPlan.Read).to eq(true)
      export = Yast::AutoinstPartPlan.Export.select { |d| d.key?("skip_list") }

      expect(export[0]).to include("initialize" => true)
      skip_list = export[0]["skip_list"]
      expect(skip_list).to all(include("skip_key" => "device"))
      expect(skip_list).to all(include("skip_value" => /\/dev\//))
    end

  end

end
